summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/decocomn.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/decocomn.cpp')
-rw-r--r--src/mame/video/decocomn.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/decocomn.cpp b/src/mame/video/decocomn.cpp
index dfff3833089..a22444754ac 100644
--- a/src/mame/video/decocomn.cpp
+++ b/src/mame/video/decocomn.cpp
@@ -23,13 +23,13 @@ decocomn_device::decocomn_device(const machine_config &mconfig, const char *tag,
}
//-------------------------------------------------
// static_set_palette_tag: Set the tag of the
// palette device
//-------------------------------------------------
-void decocomn_device::static_set_palette_tag(device_t &device, const char *tag)
+void decocomn_device::set_palette_tag(const char *tag)
{
- downcast<decocomn_device &>(device).m_palette.set_tag(tag);
+ m_palette.set_tag(tag);
}
//-------------------------------------------------
@@ -23,13 +23,13 @@ decocomn_device::decocomn_device(const machine_config &mconfig, const char *tag,
}
//-------------------------------------------------
-// static_set_palette_tag: Set the tag of the
+// set_palette_tag: Set the tag of the
// palette device
//-------------------------------------------------